/* This file is part of the KDE project
   Copyright (C) 2002, Sven Lppken <sven@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
*/

#ifndef __KONTOURIMPORT_H__
#define __KONTOURIMPORT_H__

#include <KoFilter.h>
#include <tqdom.h>
#include <core/vdocument.h>

class KontourImport : public KoFilter
{
	TQ_OBJECT
  

public:
	KontourImport(KoFilter *parent, const char *name, const TQStringList&);
	virtual ~KontourImport();

	virtual KoFilter::ConversionStatus convert(const TQCString& from, const TQCString& to);

protected:
	TQDomDocument inpdoc;
	TQDomDocument outdoc;
	void convert();

private:
	void parseGObject( VObject *, const TQDomElement & );
	void parseGroup( const TQDomElement & );
	VDocument m_document;
};

#endif // __KONTOURIMPORT_H__
